'use strict';

var tuicallEngineWebrtc = require('tuicall-engine-webrtc');
var vue = require('vue');

let timer = 0;
let timerIncrease;
const timerString = vue.ref("");
function timerStart() {
    if (timer !== 0)
        return false;
    timerIncrease = setInterval(() => {
        timer += 1;
        timerString.value = getTimer();
    }, 1000);
    return true;
}
function timerClear() {
    clearInterval(timerIncrease);
    timer = 0;
}
function getTimer() {
    const h = Math.floor(timer / 3600);
    const m = Math.floor(((timer / 60) % 60));
    const s = Math.floor((timer % 60));
    let result = `${s}`;
    if (s < 10)
        result = `0${s}`;
    result = `${m}:${result}`;
    if (m < 10)
        result = `0${result}`;
    if (h > 10)
        result = `${h}:${result}`;
    else if (h > 0)
        result = `0${h}:${result}`;
    return result;
}

const STATUS = {
    IDLE: 'idle',
    BE_INVITED: 'be-invited',
    DIALING_C2C: 'dialing-c2c',
    DIALING_GROUP: 'dialing-group',
    CALLING_C2C_AUDIO: 'calling-c2c-audio',
    CALLING_C2C_VIDEO: 'calling-c2c-video',
    CALLING_GROUP_AUDIO: 'calling-group-audio',
    CALLING_GROUP_VIDEO: 'calling-group-video',
};
const CHANGE_STATUS_REASON = {
    REJECT: 'change-status-because-of-rejected',
    NO_RESPONSE: 'change-status-because-of-no-response',
    LINE_BUSY: 'change-status-because-of-line-busy',
    CALLING_CANCEL: 'change-status-because-of-calling-cancel',
    CALLING_TIMEOUT: 'change-status-because-of-calling-timeout',
    CALL_TYPE_CHANGED: ' call-type-changed',
};
const CALL_TYPE_STRING = {
    VIDEO: 'call-type-string-video',
    AUDIO: 'call-type-string-audio',
};

const status = vue.ref(STATUS.IDLE);
const isMinimized = vue.ref(false);
const dialingInfo = vue.ref("waiting");
const callType = vue.ref();
const isFromGroup = vue.ref(false);
const remoteList = vue.ref([]);
const profile = vue.ref({
    userID: "not login",
    isEntered: true,
    microphone: true,
    camera: true,
    volume: 0
});
vue.watch(timerString, () => {
    changeDialingInfo(timerString.value);
});
vue.watch(status, () => {
    if (status.value === STATUS.BE_INVITED) {
        changeDialingInfo(`发起的${callType.value === CALL_TYPE_STRING.AUDIO ? '语音通话' : '视频通话'}`);
    }
    if (status.value.split('-')[0] === "dialing") {
        changeDialingInfo("等待接听...");
    }
    if (status.value.split('-')[0] === "calling") {
        changeDialingInfo("");
        timerStart();
    }
    if (status.value === STATUS.IDLE) {
        changeDialingInfo(`发起的${callType.value === CALL_TYPE_STRING.AUDIO ? '语音通话' : '视频通话'}`);
        profile.value.microphone = true;
        profile.value.camera = true;
        isMinimized.value = false;
        changeDialingInfo("");
        changeRemoteList([]);
        TUICallKitServer.afterCalling && TUICallKitServer.afterCalling();
    }
});
function changeStatus(newValue, reason, timeout = 0) {
    console.log("TUICallKit Status: " + newValue);
    if (reason !== CHANGE_STATUS_REASON.CALL_TYPE_CHANGED) {
        console.log("TUICallKit timerClear");
        timerClear();
    }
    switch (reason) {
        case CHANGE_STATUS_REASON.REJECT:
            changeDialingInfo(`对方已拒绝，${callType.value === CALL_TYPE_STRING.AUDIO ? '语音通话' : '视频通话'}结束`);
            break;
        case CHANGE_STATUS_REASON.NO_RESPONSE:
            changeDialingInfo(`对方无应答，${callType.value === CALL_TYPE_STRING.AUDIO ? '语音通话' : '视频通话'}结束`);
            break;
        case CHANGE_STATUS_REASON.LINE_BUSY:
            changeDialingInfo(`对方忙线中，${callType.value === CALL_TYPE_STRING.AUDIO ? '语音通话' : '视频通话'}结束`);
            break;
        case CHANGE_STATUS_REASON.CALLING_CANCEL:
            changeDialingInfo(`对方已取消`);
            break;
        case CHANGE_STATUS_REASON.CALLING_TIMEOUT:
            changeDialingInfo(`本次通话超时未应答`);
            break;
        default:
            changeDialingInfo(``);
            break;
    }
    setTimeout(() => {
        TUICallKitServer.statusChanged && TUICallKitServer.statusChanged({ oldStatus: status.value, newStatus: newValue });
        status.value = newValue;
    }, timeout);
}
function addRemoteListByUserID(userID) {
    const isExisted = remoteList.value.findIndex((item) => item.userID === userID);
    if (isExisted >= 0) {
        remoteList.value[isExisted].isEntered = true;
    }
    else {
        changeRemoteList([...remoteList.value, {
                userID,
                isEntered: true,
            }]);
    }
}
function removeRemoteListByUserID(userID) {
    const isExisted = remoteList.value.findIndex((item) => item.userID === userID);
    if (isExisted >= 0) {
        const resArray = remoteList.value;
        resArray.splice(isExisted, 1);
        changeRemoteList([...resArray]);
    }
    return remoteList.value.length;
}
function changeRemoteDeviceByUserID(userID, deviceType, value) {
    const isExisted = remoteList.value.findIndex((item) => item.userID === userID);
    if (isExisted >= 0) {
        if (deviceType === CALL_TYPE_STRING.VIDEO)
            remoteList.value[isExisted].camera = value;
        else if (deviceType === CALL_TYPE_STRING.AUDIO)
            remoteList.value[isExisted].microphone = value;
    }
}
function updateRemoteVolumeMap(volumeMap) {
    volumeMap.forEach((item) => {
        const { userId, audioVolume } = item;
        if (userId === profile.value.userID) {
            profile.value.volume = audioVolume;
            return;
        }
        const isExisted = remoteList.value.findIndex((item) => item.userID === userId);
        if (isExisted >= 0) {
            remoteList.value[isExisted].volume = audioVolume;
        }
    });
}
function changeDialingInfo(newValue) {
    dialingInfo.value = newValue;
}
function changeCallType(newValue) {
    if (newValue === tuicallEngineWebrtc.TUICallType.AUDIO_CALL)
        callType.value = CALL_TYPE_STRING.AUDIO;
    if (newValue === tuicallEngineWebrtc.TUICallType.VIDEO_CALL)
        callType.value = CALL_TYPE_STRING.VIDEO;
}
function changeIsFromGroup(newValue) {
    isFromGroup.value = newValue;
}
function changeRemoteList(newValue) {
    remoteList.value = newValue;
}
function updateProfile(newValue) {
    profile.value = newValue;
}
function changeIsMinimized(newValue) {
    isMinimized.value = newValue;
}

/**
 * class TUICallKit
 *
 * TUIGroup 逻辑主体
 */
class TUICallKit {
    tuiCallEngine;
    TUICore;
    beforeCalling;
    afterCalling;
    onMinimized;
    statusChanged;
    APIStatus;
    error;
    constructor() {
        this.TUICore = null;
        this.tuiCallEngine = null;
    }
    /**
     * init 初始化
     * @param { TUIInitParam } params 初始化参数
     * @param { number } params.SDKAppID
     * @param { string } params.userID
     * @param { string } params.userSig
     * @param { any= } params.tim
     */
    async init(params) {
        let { SDKAppID, tim, userID, userSig } = params;
        if (this.TUICore) {
            SDKAppID = this.TUICore.SDKAppID;
            tim = this.TUICore.tim;
        }
        if (this.tuiCallEngine)
            await this.tuiCallEngine.destroyInstance();
        this.tuiCallEngine = tuicallEngineWebrtc.TUICallEngine.createInstance({ SDKAppID, tim });
        this.bindTIMEvent();
        try {
            await this.tuiCallEngine.login({ userID, userSig });
            console.log("TUICallKit login successful");
            updateProfile(Object.assign(profile.value, { userID }));
        }
        catch (error) {
            console.error("TUICallKit login failed", JSON.stringify(error));
        }
    }
    /**
     * call 呼叫
     * @param { TUICallParam } params 呼叫参数
     * @param { string } params.userID 被呼叫的用户
     * @param { number } params.type 呼叫类型 1-语音，2-视频
     */
    async call(params) {
        if (this.APIStatus === "call") {
            return;
        }
        this.APIStatus = "call";
        this.checkStatus();
        const { userID, type } = params;
        try {
            await this.tuiCallEngine.call({ userID, type });
            this.beforeCalling && this.beforeCalling("call");
            changeStatus(STATUS.DIALING_C2C);
            changeRemoteList([{ userID, isEntered: false, microphone: false, camera: false }]);
            changeCallType(type);
            changeIsFromGroup(false);
            this.APIStatus = "";
        }
        catch (error) {
            this.beforeCalling && this.beforeCalling("call", this.error);
            this.error = null;
            this.APIStatus = "";
            console.error("TUICallKit call error: " + JSON.stringify(error));
            throw new Error(error);
        }
    }
    /**
     * groupCall 呼叫
     * @param { TUIGroupCallParam } params 呼叫参数
     * @param { string } params.userIDList 被呼叫的用户列表
     * @param { number } params.type 呼叫类型 1-语音，2-视频
     * @param { string } params.groupID 呼叫群组ID
     */
    async groupCall(params) {
        if (this.APIStatus === "groupCall") {
            return;
        }
        this.APIStatus = "groupCall";
        this.checkStatus();
        const { userIDList, type, groupID } = params;
        try {
            await this.tuiCallEngine.groupCall({ userIDList, type, groupID });
            this.beforeCalling && this.beforeCalling("groupCall");
            const newRemoteList = [];
            userIDList.forEach((userID) => {
                newRemoteList.push({ userID, isEntered: false, microphone: false, camera: false });
            });
            changeRemoteList(newRemoteList);
            changeStatus(STATUS.DIALING_GROUP);
            changeCallType(type);
            changeIsFromGroup(true);
            this.APIStatus = "";
        }
        catch (error) {
            this.beforeCalling && this.beforeCalling("groupCall", this.error);
            this.error = null;
            this.APIStatus = "";
            console.error("TUICallKit groupCall error: " + JSON.stringify(error));
            throw new Error(error);
        }
    }
    checkStatus() {
        if (status.value !== STATUS.IDLE) {
            throw new Error("TUICallKit 已在通话状态");
        }
        if (!this.tuiCallEngine) {
            throw new Error("TUICallKit 发起通话前需先进行初始化");
        }
    }
    async getDeviceList(deviceType) {
        return await this.tuiCallEngine.getDeviceList(deviceType);
    }
    async switchDevice(deviceType, deviceId) {
        try {
            await this.tuiCallEngine.switchDevice({ deviceType, deviceId });
            this.startLocalView("local");
        }
        catch (error) {
            console.error("TUICallKit switchDevice error", JSON.stringify(error));
        }
    }
    bindTUICore(TUICore) {
        this.TUICore = TUICore;
    }
    setCallback(params) {
        const { beforeCalling, afterCalling, onMinimized } = params;
        this.beforeCalling = beforeCalling;
        this.afterCalling = afterCalling;
        this.onMinimized = onMinimized;
    }
    toggleMinimize() {
        console.log("TUICallKit toggleMinimize called", isMinimized.value, "->", !isMinimized.value);
        this.onMinimized && this.onMinimized(isMinimized.value, !isMinimized.value);
        changeIsMinimized(!isMinimized.value);
    }
    async accept() {
        if (this.APIStatus === "accept") {
            return;
        }
        this.APIStatus = "accept";
        try {
            await this.tuiCallEngine.accept();
            this.getIntoCallingStatus();
        }
        catch (error) {
            console.error("TUICallKit accept error catch: ", error);
            changeStatus(STATUS.IDLE);
        }
        this.APIStatus = "";
    }
    async reject() {
        if (this.APIStatus === "reject") {
            return;
        }
        this.APIStatus = "reject";
        try {
            await this.tuiCallEngine.reject();
        }
        catch (error) {
            console.error("TUICallKit reject error catch: ", error);
        }
        changeStatus(STATUS.IDLE);
        this.APIStatus = "";
    }
    async startLocalView(local) {
        await this.tuiCallEngine.startLocalView({ userID: profile.value.userID, videoViewDomID: local });
    }
    async startRemoteView(userID) {
        await this.tuiCallEngine.startRemoteView({ userID, videoViewDomID: userID });
    }
    async hangup() {
        if (this.APIStatus === "hangup") {
            return;
        }
        this.APIStatus = "hangup";
        await this.tuiCallEngine.hangup();
        changeStatus(STATUS.IDLE);
        this.APIStatus = "";
    }
    async openCamera() {
        try {
            await this.tuiCallEngine.openCamera();
            updateProfile(Object.assign(profile.value, { camera: true }));
        }
        catch (error) {
            console.error("TUICallKit openCamera error:", error);
        }
    }
    async closeCamera() {
        try {
            await this.tuiCallEngine.closeCamera();
            updateProfile(Object.assign(profile.value, { camera: false }));
        }
        catch (error) {
            console.error("TUICallKit closeCamera error:", error);
        }
    }
    async openMicrophone() {
        try {
            await this.tuiCallEngine.openMicrophone();
            updateProfile(Object.assign(profile.value, { microphone: true }));
        }
        catch (error) {
            console.error("TUICallKit openMicrophone error:", error);
        }
    }
    async closeMicrophone() {
        try {
            await this.tuiCallEngine.closeMicrophone();
            updateProfile(Object.assign(profile.value, { microphone: false }));
        }
        catch (error) {
            console.error("TUICallKit closeMicrophone error:", error);
        }
    }
    async setVideoQuality(profile) {
        await this.tuiCallEngine.setVideoQuality(profile);
    }
    async switchCallMediaType() {
        if (this.APIStatus === "switchCallMediaType") {
            return;
        }
        this.APIStatus = "switchCallMediaType";
        try {
            await this.tuiCallEngine.switchCallMediaType(1);
        }
        catch (error) {
            console.error("TUICallKit switchCallMediaType error:", error);
        }
        this.APIStatus = "";
    }
    onStatusChanged(statusChanged) {
        this.statusChanged = statusChanged;
    }
    /**
     * 组件销毁
     */
    destroyed() {
        this.unbindTIMEvent();
        changeStatus(STATUS.IDLE);
    }
    getIntoCallingStatus() {
        if (!isFromGroup.value && callType.value === CALL_TYPE_STRING.AUDIO)
            changeStatus(STATUS.CALLING_C2C_AUDIO);
        if (!isFromGroup.value && callType.value === CALL_TYPE_STRING.VIDEO)
            changeStatus(STATUS.CALLING_C2C_VIDEO);
        if (isFromGroup.value && callType.value === CALL_TYPE_STRING.AUDIO)
            changeStatus(STATUS.CALLING_GROUP_AUDIO);
        if (isFromGroup.value && callType.value === CALL_TYPE_STRING.VIDEO)
            changeStatus(STATUS.CALLING_GROUP_VIDEO);
    }
    /**
     * /////////////////////////////////////////////////////////////////////////////////
     * //
     * //                                    TUICallEngine 事件监听注册接口
     * //
     * /////////////////////////////////////////////////////////////////////////////////
     */
    bindTIMEvent() {
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.ERROR, this.handleError, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.SDK_READY, this.handleSDKReady, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.INVITED, this.handleInvited, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.USER_ACCEPT, this.handleUserAccept, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.USER_ENTER, this.handleUserEnter, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.USER_LEAVE, this.handleUserLeave, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.REJECT, this.handleReject, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.NO_RESP, this.handleNoResponse, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.LINE_BUSY, this.handleLineBusy, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.CALLING_CANCEL, this.handleCallingCancel, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.KICKED_OUT, this.handleKickedOut, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.CALLING_TIMEOUT, this.handleCallingTimeOut, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.CALLING_END, this.handleCallingEnd, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.USER_VIDEO_AVAILABLE, this.handleUserVideoAvailable, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.USER_AUDIO_AVAILABLE, this.handleUserAudioAvailable, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.USER_VOICE_VOLUME, this.handleUserVoiceVolume, this);
        this.tuiCallEngine.on(tuicallEngineWebrtc.TUICallEvent.CALL_TYPE_CHANGED, this.handleCallTypeChanged, this);
    }
    unbindTIMEvent() {
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.ERROR, this.handleError, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.SDK_READY, this.handleSDKReady, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.INVITED, this.handleInvited);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.USER_ACCEPT, this.handleUserAccept);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.USER_ENTER, this.handleUserEnter, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.USER_LEAVE, this.handleUserLeave, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.REJECT, this.handleReject, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.NO_RESP, this.handleNoResponse, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.LINE_BUSY, this.handleLineBusy, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.CALLING_CANCEL, this.handleCallingCancel, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.KICKED_OUT, this.handleKickedOut, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.CALLING_TIMEOUT, this.handleCallingTimeOut, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.CALLING_END, this.handleCallingEnd, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.USER_VIDEO_AVAILABLE, this.handleUserVideoAvailable, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.USER_AUDIO_AVAILABLE, this.handleUserAudioAvailable, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.USER_VOICE_VOLUME, this.handleUserVoiceVolume, this);
        this.tuiCallEngine.off(tuicallEngineWebrtc.TUICallEvent.CALL_TYPE_CHANGED, this.handleCallTypeChanged, this);
    }
    handleError(event) {
        const { code } = event;
        this.error = {
            code,
            type: "",
            message: ""
        };
        switch (code) {
            case 60001:
                this.error.type = "方法调用失败";
                this.error.message = "switchToAudioCall 调用失败";
                break;
            case 60002:
                this.error.type = "方法调用失败";
                this.error.message = "switchToVideoCall 调用失败";
                break;
            case 60003:
                this.error.type = "权限获取失败";
                this.error.message = "没有可用的麦克风设备";
                break;
            case 60004:
                this.error.type = "权限获取失败";
                this.error.message = "没有可用的摄像头设备";
                break;
            case 60005:
                this.error.type = "权限获取失败";
                this.error.message = "用户禁止使用设备";
                break;
            case 60006:
                this.error.type = "环境检测失败";
                this.error.message = "当前环境不支持webRTC";
                break;
        }
        console.error("TUICallKit Error", JSON.stringify(this.error));
        if (status.value === STATUS.BE_INVITED) {
            this.beforeCalling && this.beforeCalling("invited", this.error);
        }
    }
    handleSDKReady(event) {
        console.log("TUICallKit SDK is ready.", event);
    }
    handleKickedOut() {
        console.error("TUICallKit Kicked Out", JSON.stringify(event));
    }
    handleUserVideoAvailable(event) {
        const { userID, isVideoAvailable } = event;
        changeRemoteDeviceByUserID(userID, CALL_TYPE_STRING.VIDEO, isVideoAvailable);
    }
    handleUserAudioAvailable(event) {
        const { userID, isAudioAvailable } = event;
        changeRemoteDeviceByUserID(userID, CALL_TYPE_STRING.AUDIO, isAudioAvailable);
    }
    handleUserVoiceVolume(event) {
        const { volumeMap } = event;
        updateRemoteVolumeMap(volumeMap);
    }
    handleInvited(event) {
        console.log("TUICallKit handleInvited", event);
        this.beforeCalling && this.beforeCalling("invited", this.error);
        if (this.error) {
            this.reject();
            this.error = null;
            return;
        }
        const { sponsor, isFromGroup, inviteData } = event;
        const { callType } = inviteData;
        changeStatus(STATUS.BE_INVITED);
        changeRemoteList([{ userID: sponsor, isEntered: false }]);
        changeCallType(callType);
        changeIsFromGroup(isFromGroup);
    }
    handleUserAccept(event) {
        console.log("TUICallKit handleUserAccept", event);
        const { userID } = event;
        if (userID !== profile.value.userID)
            return;
        if (status.value === STATUS.BE_INVITED)
            return;
        this.getIntoCallingStatus();
    }
    handleUserEnter(event) {
        console.log("TUICallKit handleUserEnter", event);
        const { userID } = event;
        addRemoteListByUserID(userID);
    }
    handleUserLeave(event) {
        console.log("TUICallKit handleUserLeave", event);
        const { userID } = event;
        removeRemoteListByUserID(userID);
    }
    handleReject(event) {
        console.log("TUICallKit handleReject", event);
        const { userID } = event;
        if (status.value === STATUS.BE_INVITED)
            return;
        if (status.value === STATUS.CALLING_GROUP_AUDIO || status.value === STATUS.CALLING_GROUP_VIDEO || status.value === STATUS.DIALING_GROUP) {
            removeRemoteListByUserID(userID);
            return;
        }
        changeStatus(STATUS.IDLE, CHANGE_STATUS_REASON.REJECT, 1000);
    }
    handleNoResponse(event) {
        console.log("TUICallKit handleNoResponse", event);
        const { userIDList } = event;
        userIDList.forEach((userID) => {
            if (removeRemoteListByUserID(userID) <= 0) {
                changeStatus(STATUS.IDLE, CHANGE_STATUS_REASON.NO_RESPONSE, isFromGroup.value ? 0 : 1000);
            }
        });
    }
    handleLineBusy(event) {
        console.log("TUICallKit handleLineBusy", event);
        changeStatus(STATUS.IDLE, CHANGE_STATUS_REASON.LINE_BUSY, 1000);
    }
    handleCallingCancel(event) {
        console.log("TUICallKit handleCallingCancel", event);
        changeStatus(STATUS.IDLE, CHANGE_STATUS_REASON.CALLING_CANCEL, 1000);
    }
    handleCallingTimeOut(event) {
        console.log("TUICallKit handleCallingTimeOut", event);
        const { userIDList } = event;
        userIDList.forEach((userID) => {
            if (removeRemoteListByUserID(userID) <= 0 || userID === profile.value.userID) {
                changeStatus(STATUS.IDLE, CHANGE_STATUS_REASON.CALLING_TIMEOUT, isFromGroup.value ? 0 : 1000);
            }
        });
    }
    handleCallingEnd(event) {
        console.log("TUICallKit handleCallingEnd", event);
        changeStatus(STATUS.IDLE);
    }
    handleCallTypeChanged(event) {
        console.log("TUICallKit handleCallTypeChanged", event);
        const { newCallType } = event;
        changeCallType(newCallType);
        changeStatus(STATUS.CALLING_C2C_AUDIO, CHANGE_STATUS_REASON.CALL_TYPE_CHANGED);
    }
}

const _hoisted_1$q = {
    xmlns: "http://www.w3.org/2000/svg",
    fill: "none",
    viewBox: "0 0 16 16",
    class: "design-iconfont"
};
const _hoisted_2$p = { key: 0 };
const _hoisted_3$p = /*#__PURE__*/ vue.createElementVNode("path", {
    d: "M8.62462 7.17395C8.90076 7.17395 9.12462 7.38807 9.12462 7.65221C9.12462 7.89434 8.93651 8.09444 8.69246 8.12611L8.62462 8.13047H7.3335C7.05735 8.13047 6.8335 7.91635 6.8335 7.65221C6.8335 7.41009 7.0216 7.20998 7.26565 7.17832L7.3335 7.17395H8.62462Z",
    fill: "#43D92B"
}, null, -1 /* HOISTED */);
const _hoisted_4$j = [
    _hoisted_3$p
];
const _hoisted_5$9 = { key: 1 };
const _hoisted_6$5 = /*#__PURE__*/ vue.createElementVNode("path", {
    d: "M8.62462 5.57971C8.90076 5.57971 9.12462 5.79384 9.12462 6.05797C9.12462 6.3001 8.93651 6.5002 8.69246 6.53187L8.62462 6.53623H7.3335C7.05735 6.53623 6.8335 6.32211 6.8335 6.05797C6.8335 5.81585 7.0216 5.61575 7.26565 5.58408L7.3335 5.57971H8.62462Z",
    fill: "#43D92B"
}, null, -1 /* HOISTED */);
const _hoisted_7$2 = [
    _hoisted_6$5
];
const _hoisted_8$2 = { key: 2 };
const _hoisted_9$2 = /*#__PURE__*/ vue.createElementVNode("path", {
    d: "M8.62462 3.98547C8.90076 3.98547 9.12462 4.1996 9.12462 4.46373C9.12462 4.70586 8.93651 4.90596 8.69246 4.93763L8.62462 4.942H7.3335C7.05735 4.942 6.8335 4.72787 6.8335 4.46373C6.8335 4.22161 7.0216 4.02151 7.26565 3.98984L7.3335 3.98547H8.62462Z",
    fill: "#43D92B"
}, null, -1 /* HOISTED */);
const _hoisted_10$2 = [
    _hoisted_9$2
];
const _hoisted_11$1 = /*#__PURE__*/ vue.createElementVNode("path", {
    "fill-rule": "evenodd",
    "clip-rule": "evenodd",
    d: "M11.3301 3.45938C11.2517 1.89175 9.77808 0.658081 8 0.658081C6.17253 0.658081 4.66667 1.96123 4.66667 3.59077V7.72539L4.66994 7.85678C4.7483 9.42442 6.22192 10.6581 8 10.6581C9.82747 10.6581 11.3333 9.35493 11.3333 7.72539V3.59077L11.3301 3.45938ZM6.0035 3.54179C6.06337 2.69234 6.92083 1.99146 8.00016 1.99146C9.11947 1.99146 10.0002 2.74521 10.0002 3.63675V7.67949L9.99682 7.77446C9.93695 8.62391 9.07949 9.32479 8.00016 9.32479C6.88086 9.32479 6.00016 8.57103 6.00016 7.67949V3.63675L6.0035 3.54179ZM8.33333 15.3333C8.51743 15.3333 8.66667 15.1841 8.66667 15V13.2964C11.5402 12.9793 14 10.6655 14 8.27322V7.68092C14 7.49682 13.8508 7.34758 13.6667 7.34758H13C12.8159 7.34758 12.6667 7.49682 12.6667 7.68092V8.27322L12.6634 8.39309C12.5681 10.1524 10.3982 11.9979 8.00396 12C8.00264 12 8.00132 12 8 12C7.99868 12 7.99736 12 7.99604 12C5.54737 11.9979 3.33333 10.0675 3.33333 8.27322L3.33043 7.65652C3.32956 7.47164 3.17839 7.32278 2.99352 7.32477L2.32975 7.33191C2.14706 7.33387 2 7.48252 2 7.66522V8.27322L2.00292 8.4162C2.09825 10.757 4.51708 12.9856 7.33333 13.2964V15C7.33333 15.1841 7.48257 15.3333 7.66667 15.3333H8.33333Z",
    fill: "#fff"
}, null, -1 /* HOISTED */);
var script$q = /*#__PURE__*/ vue.defineComponent({
    __name: 'MicrophoneIcon',
    props: {
        volume: { type: Number, required: false }
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$q, [
                (__props.volume && __props.volume > 0)
                    ? (vue.openBlock(), vue.createElementBlock("g", _hoisted_2$p, _hoisted_4$j))
                    : vue.createCommentVNode("v-if", true),
                (__props.volume && __props.volume > 5)
                    ? (vue.openBlock(), vue.createElementBlock("g", _hoisted_5$9, _hoisted_7$2))
                    : vue.createCommentVNode("v-if", true),
                (__props.volume && __props.volume > 10)
                    ? (vue.openBlock(), vue.createElementBlock("g", _hoisted_8$2, _hoisted_10$2))
                    : vue.createCommentVNode("v-if", true),
                _hoisted_11$1
            ]));
        };
    }
});

script$q.__file = "src/components/MicrophoneIcon.vue";

const _hoisted_1$p = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 16 16",
  class: "design-iconfont"
};
const _hoisted_2$o = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M4.82825 12.4759C5.58172 12.9048 6.43742 13.1978 7.33333 13.2967V15.0002C7.33333 15.1843 7.48257 15.3335 7.66667 15.3335H8.33333C8.51743 15.3335 8.66667 15.1843 8.66667 15.0002V13.2967C11.5402 12.9796 14 10.6658 14 8.27347V7.68116C14 7.49707 13.8508 7.34783 13.6667 7.34783H13C12.8159 7.34783 12.6667 7.49707 12.6667 7.68116V8.27347L12.6634 8.39333C12.5681 10.1526 10.3982 11.9982 8.00396 12.0002L8 12.0002L7.99604 12.0002C7.22514 11.9996 6.47749 11.8078 5.81487 11.4893L4.82825 12.4759ZM6.83168 10.4725C7.196 10.5927 7.5899 10.6583 8 10.6583C9.82747 10.6583 11.3333 9.35517 11.3333 7.72563V5.97083L6.83168 10.4725ZM10.9068 2.1547L4.73629 8.32524C4.70043 8.17327 4.67793 8.01689 4.66994 7.85702L4.66667 7.72563V3.59102C4.66667 1.96148 6.17253 0.658325 8 0.658325C9.24072 0.658325 10.3332 1.25901 10.9068 2.1547ZM3.62455 9.43698L2.64622 10.4153C2.26208 9.78985 2.03108 9.10804 2.00292 8.41644L2 8.27347V7.66546C2 7.48277 2.14706 7.33411 2.32975 7.33215L2.99352 7.32502C3.17839 7.32303 3.32956 7.47188 3.33043 7.65676L3.33333 8.27347C3.33333 8.66191 3.4371 9.05672 3.62455 9.43698Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_3$o = /*#__PURE__*/vue.createElementVNode("rect", {
  x: ".609863",
  y: "13.4514",
  width: "19.0127",
  height: "1.5",
  rx: ".75",
  transform: "rotate(-45 .609863 13.4514)",
  fill: "#FE3C44"
}, null, -1 /* HOISTED */);
const _hoisted_4$i = [
  _hoisted_2$o,
  _hoisted_3$o
];

function render$i(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$p, _hoisted_4$i))
}

const script$p = {};


script$p.render = render$i;
script$p.__file = "src/icons/microphoneClosed.vue";

const _hoisted_1$o = { class: "dialing-wrapper" };
const _hoisted_2$n = { class: "dialing-content" };
const _hoisted_3$n = { class: "dialing-user-id" };
const _hoisted_4$h = {
    key: 1,
    class: "microphone-icon-container"
};
const _hoisted_5$8 = { class: "dialing-info" };
var script$o = /*#__PURE__*/ vue.defineComponent({
    __name: 'Dialing',
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$o, [
                vue.createElementVNode("div", _hoisted_2$n, [
                    vue.createElementVNode("div", _hoisted_3$n, [
                        (vue.unref(remoteList).length >= 1)
                            ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
                                vue.createTextVNode(vue.toDisplayString(vue.unref(remoteList)[0].userID), 1 /* TEXT */)
                            ], 64 /* STABLE_FRAGMENT */))
                            : vue.createCommentVNode("v-if", true),
                        (vue.unref(status) === vue.unref(STATUS).CALLING_C2C_AUDIO)
                            ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_4$h, [
                                (vue.unref(remoteList)[0]?.microphone)
                                    ? (vue.openBlock(), vue.createBlock(script$q, {
                                        key: 0,
                                        volume: vue.unref(remoteList)[0]?.volume
                                    }, null, 8 /* PROPS */, ["volume"]))
                                    : (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
                                        vue.createCommentVNode(" <img :src=\"microphoneClosedSVG\" v-if=\"!remoteList[0]?.microphone\" /> "),
                                        vue.createVNode(script$p)
                                    ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */))
                            ]))
                            : vue.createCommentVNode("v-if", true)
                    ]),
                    vue.createElementVNode("div", _hoisted_5$8, vue.toDisplayString(vue.unref(dialingInfo)), 1 /* TEXT */)
                ])
            ]));
        };
    }
});

script$o.__file = "src/components/Dialing.vue";

const _hoisted_1$n = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 12 12",
  class: "design-iconfont"
};
const _hoisted_2$m = /*#__PURE__*/vue.createElementVNode("path", {
  opacity: ".01",
  transform: "matrix(1 0 0 -1 0 12)",
  fill: "#000",
  d: "M0 0H12V12H0z"
}, null, -1 /* HOISTED */);
const _hoisted_3$m = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M9.14646 7.14643C9.46144 7.46141 9.23835 7.99998 8.7929 7.99998L3.20712 7.99998C2.76167 7.99998 2.53859 7.4614 2.85357 7.14642L5.6465 4.35355C5.84177 4.15829 6.15835 4.15829 6.35361 4.35355L9.14646 7.14643Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$g = [
  _hoisted_2$m,
  _hoisted_3$m
];

function render$h(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$n, _hoisted_4$g))
}

const script$n = {};


script$n.render = render$h;
script$n.__file = "src/icons/triangle.vue";

const _hoisted_1$m = { class: "control-item" };
const _hoisted_2$l = { class: "control-item-icon" };
const _hoisted_3$l = { class: "control-item-detail" };
const _hoisted_4$f = { class: "control-item-text" };
var script$m = /*#__PURE__*/ vue.defineComponent({
    __name: 'ControlPanelItem',
    props: {
        action: { type: Function, required: true },
        hasDetail: { type: Boolean, required: false, default: false }
    },
    setup(__props) {
        const { action, hasDetail } = __props;
        const openDetail = vue.ref(false);
        vue.onMounted(() => {
            document.documentElement.addEventListener('click', (e) => {
                openDetail.value = false;
            });
        });
        async function stayFocus() {
            await vue.nextTick();
            const els = document.getElementsByClassName("control-item-detail");
            for (let el of els) {
                el.addEventListener("click", e => e.stopPropagation());
            }
        }
        const toggleDetail = (event) => {
            event.stopPropagation();
            stayFocus();
            openDetail.value = !openDetail.value;
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$m, [
                vue.createElementVNode("div", _hoisted_2$l, [
                    vue.createElementVNode("div", {
                        class: "control-item-icon-container",
                        onClick: action
                    }, [
                        vue.renderSlot(_ctx.$slots, "icon")
                    ]),
                    hasDetail
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 0,
                            class: "control-item-summary",
                            onClick: toggleDetail
                        }, [
                            vue.createCommentVNode(" <img :src=\"triangleSVG\" /> "),
                            vue.createVNode(script$n)
                        ]))
                        : vue.createCommentVNode("v-if", true),
                    vue.withDirectives(vue.createElementVNode("div", _hoisted_3$l, [
                        vue.renderSlot(_ctx.$slots, "detail")
                    ], 512 /* NEED_PATCH */), [
                        [vue.vShow, openDetail.value]
                    ])
                ]),
                vue.createElementVNode("div", _hoisted_4$f, [
                    vue.createElementVNode("text", null, [
                        vue.renderSlot(_ctx.$slots, "text")
                    ])
                ])
            ]));
        };
    }
});

script$m.__file = "src/components/ControlPanelItem.vue";

const _hoisted_1$l = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 40 40",
  class: "design-iconfont"
};
const _hoisted_2$k = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M0 20C0 8.95431 8.95431 0 20 0C31.0457 0 40 8.95431 40 20C40 31.0457 31.0457 40 20 40C8.95431 40 0 31.0457 0 20Z",
  fill: "#FE3C44"
}, null, -1 /* HOISTED */);
const _hoisted_3$k = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M25.4437 20.449C25.4437 22.1142 25.2336 23.3515 28.5089 23.7126C31.7875 24.0737 31.3666 21.6794 31.3662 20.0669C31.3649 18.2061 27.0602 15.619 20.2726 15.6173C13.4866 15.6173 9.1789 18.205 9.17888 20.067C9.17887 21.68 8.75621 24.0726 12.0332 23.7123C15.3101 23.3537 15.1 22.1155 15.0984 20.4495C15.1013 19.2862 17.7587 19.0316 20.2725 19.0298C22.7863 19.0281 25.4454 19.2844 25.4437 20.449Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$e = [
  _hoisted_2$k,
  _hoisted_3$k
];

function render$g(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$l, _hoisted_4$e))
}

const script$l = {};


script$l.render = render$g;
script$l.__file = "src/icons/reject.vue";

const _hoisted_1$k = {
  width: "40",
  height: "40",
  viewBox: "0 0 40 40",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$j = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M0 20C0 8.95431 8.95431 0 20 0V0C31.0457 0 40 8.95431 40 20V20C40 31.0457 31.0457 40 20 40V40C8.95431 40 0 31.0457 0 20V20Z",
  fill: "#19D255"
}, null, -1 /* HOISTED */);
const _hoisted_3$j = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M23.5397 16.9535C24.7172 18.131 25.4436 19.1544 28.0149 17.0938C30.5885 15.0308 28.5979 13.6354 27.4573 12.4955C26.1407 11.1806 21.2674 12.3951 16.4667 17.1935C11.6683 21.9919 10.4521 26.8677 11.7687 28.1844C12.9092 29.3249 14.3022 31.3156 16.3646 28.7437C18.4282 26.173 17.4041 25.446 16.2248 24.2691C15.4043 23.4444 17.1034 21.3853 18.8797 19.6066C20.656 17.8278 22.7174 16.1288 23.5397 16.9535Z",
  fill: "white"
}, null, -1 /* HOISTED */);
const _hoisted_4$d = [
  _hoisted_2$j,
  _hoisted_3$j
];

function render$f(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$k, _hoisted_4$d))
}

const script$k = {};


script$k.render = render$f;
script$k.__file = "src/icons/acceptAudio.vue";

const _hoisted_1$j = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 40 40",
  class: "design-iconfont"
};
const _hoisted_2$i = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M0 20C0 8.95431 8.95431 0 20 0C31.0457 0 40 8.95431 40 20C40 31.0457 31.0457 40 20 40C8.95431 40 0 31.0457 0 20Z",
  fill: "#19D255"
}, null, -1 /* HOISTED */);
const _hoisted_3$i = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M24.0421 14.8129C23.8814 14.0792 23.3684 13.5231 22.7291 13.3902C21.6674 13.2126 20.3495 13 17.6667 13C14.7319 13 13.5011 13.2009 12.5263 13.3669C11.9235 13.5295 11.4484 14.0688 11.2926 14.7675C11.153 15.6419 11 17.8298 11 19.6667C11 21.4724 11.1481 23.6461 11.2912 24.5205C11.4519 25.2542 11.9649 25.8103 12.6042 25.9431C13.666 26.1207 14.9839 26.3333 17.6667 26.3333C20.3495 26.3333 21.6674 26.1207 22.7305 25.9522C23.3726 25.8194 23.8891 25.26 24.0512 24.5231C24.1853 23.6461 24.3333 21.4724 24.3333 19.6667C24.3333 17.8609 24.1853 15.6872 24.0421 14.8129ZM12.6667 15.5C12.6667 15.0398 13.0398 14.6667 13.5 14.6667H14.3333C14.7936 14.6667 15.1667 15.0398 15.1667 15.5C15.1667 15.9602 14.7936 16.3333 14.3333 16.3333H13.5C13.0398 16.3333 12.6667 15.9602 12.6667 15.5ZM28.5 14.6667C27.0942 14.6667 26 16.547 26 17.6429V21.6905C26 22.9804 26.8008 24.6667 28.5 24.6667C29.2858 24.6667 29.3333 21.4524 29.3333 19.6667C29.3333 17.881 29.3333 14.6667 28.5 14.6667Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$c = [
  _hoisted_2$i,
  _hoisted_3$i
];

function render$e(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$j, _hoisted_4$c))
}

const script$j = {};


script$j.render = render$e;
script$j.__file = "src/icons/acceptVideo.vue";

const _hoisted_1$i = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 40 40",
  class: "design-iconfont"
};
const _hoisted_2$h = /*#__PURE__*/vue.createElementVNode("rect", {
  width: "40",
  height: "40",
  rx: "20",
  fill: "#DADADA",
  "fill-opacity": ".3"
}, null, -1 /* HOISTED */);
const _hoisted_3$h = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M24.0164 14.5395C23.8498 13.7141 23.3182 13.0884 22.6556 12.939C21.5553 12.7392 20.1895 12.5 17.4091 12.5C14.3676 12.5 13.092 12.726 12.0818 12.9127C11.4571 13.0957 10.9647 13.7024 10.8033 14.4884C10.6585 15.4721 10.5 17.9335 10.5 20C10.5 22.0315 10.6535 24.4769 10.8018 25.4605C10.9684 26.2859 11.5 26.9116 12.1625 27.061C13.2629 27.2608 14.6287 27.5 17.4091 27.5C20.1895 27.5 21.5553 27.2608 22.6571 27.0712C23.3225 26.9218 23.8578 26.2925 24.0258 25.4634C24.1647 24.4769 24.3182 22.0315 24.3182 20C24.3182 17.9685 24.1647 15.5231 24.0164 14.5395ZM12.2273 15.2083C12.2273 14.7481 12.6004 14.375 13.0606 14.375H13.9848C14.4451 14.375 14.8182 14.7481 14.8182 15.2083V15.4167C14.8182 15.8769 14.4451 16.25 13.9848 16.25H13.0606C12.6004 16.25 12.2273 15.8769 12.2273 15.4167V15.2083ZM28.6364 14.375C27.1794 14.375 26.0455 16.4904 26.0455 17.7232V22.2768C26.0455 23.7279 26.8754 25.625 28.6364 25.625C29.4508 25.625 29.5 22.0089 29.5 20C29.5 17.9911 29.5 14.375 28.6364 14.375Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$b = [
  _hoisted_2$h,
  _hoisted_3$h
];

function render$d(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$i, _hoisted_4$b))
}

const script$i = {};


script$i.render = render$d;
script$i.__file = "src/icons/camera.vue";

const _hoisted_1$h = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 40 40",
  class: "design-iconfont"
};
const _hoisted_2$g = /*#__PURE__*/vue.createElementVNode("rect", {
  width: "40",
  height: "40",
  rx: "20",
  fill: "#DADADA",
  "fill-opacity": ".3"
}, null, -1 /* HOISTED */);
const _hoisted_3$g = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M16.6665 14.1667C16.6665 12.3284 18.1615 10.8334 19.9998 10.8334C21.8382 10.8334 23.3332 12.3284 23.3332 14.1667V19.1667C23.3332 21.005 21.8382 22.5 19.9998 22.5C18.1615 22.5 16.6665 21.005 16.6665 19.1667V14.1667ZM16.6665 28.3334C16.6665 27.8725 17.0398 27.5 17.4998 27.5H22.4998C22.9607 27.5 23.3332 27.8725 23.3332 28.3334C23.3332 28.7942 22.9607 29.1667 22.4998 29.1667H17.4998C17.0398 29.1667 16.6665 28.7942 16.6665 28.3334Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$a = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M25.8332 18.3512V19.5083C25.8332 22.0811 23.2215 25 19.9998 25C16.7782 25 14.1665 22.0811 14.1665 19.5083V18.3334",
  stroke: "#fff",
  "stroke-width": "1.66667",
  "stroke-linecap": "round"
}, null, -1 /* HOISTED */);
const _hoisted_5$7 = [
  _hoisted_2$g,
  _hoisted_3$g,
  _hoisted_4$a
];

function render$c(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$h, _hoisted_5$7))
}

const script$h = {};


script$h.render = render$c;
script$h.__file = "src/icons/microphone.vue";

const _hoisted_1$g = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 40 40",
  class: "design-iconfont"
};
const _hoisted_2$f = /*#__PURE__*/vue.createElementVNode("rect", {
  width: "40",
  height: "40",
  rx: "20",
  fill: "#DADADA",
  "fill-opacity": ".3"
}, null, -1 /* HOISTED */);
const _hoisted_3$f = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M17.7311 15.7485C17.7311 15.4339 18.1333 15.289 18.3596 15.507L22.9808 19.6831C23.1314 19.828 23.1314 20.0453 22.9808 20.166L18.3341 24.3435C18.1086 24.5608 17.7063 24.3917 17.7063 24.102V22.3396C17.7063 22.1464 17.5303 22.0016 17.3296 22.0016C14.2147 22.074 12.4319 22.8707 10.649 24.5366C10.3726 24.778 9.89538 24.5366 10.0205 24.1986C11.1007 21.1565 12.9345 18.4042 17.7311 17.8006V15.7485Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$9 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M24.7603 17.0411C26.4103 18.6911 26.4328 21.3438 24.8106 22.9661C24.5788 23.1978 24.1999 23.1946 23.9642 22.9589C23.7284 22.7232 23.7252 22.3442 23.957 22.1124C25.1157 20.9537 25.0996 19.0589 23.9211 17.8803C23.6853 17.6446 23.6821 17.2656 23.9139 17.0339C24.1456 16.8021 24.5246 16.8053 24.7603 17.0411Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_5$6 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M26.8765 14.925C29.7051 17.7536 29.7437 22.3011 26.9627 25.0821C26.731 25.3138 26.352 25.3106 26.1163 25.0749C25.8806 24.8392 25.8773 24.4602 26.1091 24.2285C28.4266 21.911 28.3944 18.1214 26.0373 15.7642C25.8016 15.5285 25.7983 15.1495 26.0301 14.9178C26.2618 14.686 26.6408 14.6893 26.8765 14.925Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_6$4 = [
  _hoisted_2$f,
  _hoisted_3$f,
  _hoisted_4$9,
  _hoisted_5$6
];

function render$b(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$g, _hoisted_6$4))
}

const script$g = {};


script$g.render = render$b;
script$g.__file = "src/icons/switch.vue";

const _hoisted_1$f = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 40 40",
  class: "design-iconfont"
};
const _hoisted_2$e = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M0 20C0 8.95431 8.95431 0 20 0C31.0457 0 40 8.95431 40 20C40 31.0457 31.0457 40 20 40C8.95431 40 0 31.0457 0 20Z",
  fill: "#FE3C44"
}, null, -1 /* HOISTED */);
const _hoisted_3$e = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M25.4437 20.449C25.4437 22.1142 25.2336 23.3515 28.5089 23.7126C31.7875 24.0737 31.3666 21.6794 31.3662 20.0669C31.3649 18.2061 27.0602 15.619 20.2726 15.6173C13.4866 15.6173 9.1789 18.205 9.17888 20.067C9.17887 21.68 8.75621 24.0726 12.0332 23.7123C15.3101 23.3537 15.1 22.1155 15.0984 20.4495C15.1013 19.2862 17.7587 19.0316 20.2725 19.0298C22.7863 19.0281 25.4454 19.2844 25.4437 20.449Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$8 = [
  _hoisted_2$e,
  _hoisted_3$e
];

function render$a(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$f, _hoisted_4$8))
}

const script$f = {};


script$f.render = render$a;
script$f.__file = "src/icons/hangup.vue";

const _hoisted_1$e = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 40 40",
  class: "design-iconfont"
};
const _hoisted_2$d = /*#__PURE__*/vue.createElementVNode("rect", {
  opacity: ".3",
  width: "40",
  height: "40",
  rx: "20",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_3$d = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M20 11.5C18.0697 11.5 16.5 12.9678 16.5 14.7727V19.6818C16.5 20.2623 16.6623 20.8078 16.9468 21.281L23.4997 14.7281C23.4741 12.9437 21.9143 11.5 20 11.5ZM23.5 18.9704L19.5436 22.9269C19.693 22.9451 19.8453 22.9545 20 22.9545C21.9303 22.9545 23.5 21.4867 23.5 19.6818V18.9704ZM15.7321 22.4957C15.1207 21.7452 14.75 20.8727 14.75 20.0171V18.8636L14.7432 18.761C14.6892 18.3575 14.3211 18.0454 13.875 18.0454C13.3918 18.0454 13 18.4117 13 18.8636V20.0171L13.0047 20.2215C13.0611 21.4647 13.6284 22.6883 14.5245 23.7033L15.7321 22.4957ZM16.9482 25.5222L18.2094 24.261C18.7777 24.4715 19.3834 24.5909 20 24.5909C22.6589 24.5909 25.1138 22.3716 25.2445 20.1981L25.25 20.0171V18.8811C25.25 18.4293 25.6418 18.0629 26.125 18.0629C26.5711 18.0629 26.9392 18.3751 26.9932 18.7785L27 18.8811V20.0171C27 23.1518 23.6976 26.2272 20 26.2272C18.9256 26.2272 17.8845 25.9676 16.9482 25.5222ZM16.5 28.6818C16.5 28.2294 16.892 27.8636 17.375 27.8636H22.625C23.1089 27.8636 23.5 28.2294 23.5 28.6818C23.5 29.1343 23.1089 29.5 22.625 29.5H17.375C16.892 29.5 16.5 29.1343 16.5 28.6818Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$7 = /*#__PURE__*/vue.createElementVNode("rect", {
  x: "27.249",
  y: "11.7688",
  width: "1.5",
  height: "22",
  rx: ".75",
  transform: "rotate(45 27.249 11.7688)",
  fill: "#FE3C44"
}, null, -1 /* HOISTED */);
const _hoisted_5$5 = [
  _hoisted_2$d,
  _hoisted_3$d,
  _hoisted_4$7
];

function render$9(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$e, _hoisted_5$5))
}

const script$e = {};


script$e.render = render$9;
script$e.__file = "src/icons/microphoneClosedBig.vue";

const _hoisted_1$d = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 40 40",
  class: "design-iconfont"
};
const _hoisted_2$c = /*#__PURE__*/vue.createElementVNode("rect", {
  width: "40",
  height: "40",
  rx: "20",
  fill: "#DADADA",
  "fill-opacity": ".3"
}, null, -1 /* HOISTED */);
const _hoisted_3$c = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M22.7221 12.9557C22.7001 12.9496 22.6779 12.944 22.6556 12.939C21.5553 12.7392 20.1895 12.5 17.4091 12.5C14.3676 12.5 13.092 12.726 12.0818 12.9127C11.4571 13.0957 10.9647 13.7024 10.8033 14.4884C10.6585 15.4721 10.5 17.9335 10.5 20C10.5 21.7343 10.6118 23.7703 10.7369 24.9409L22.7221 12.9557ZM12.755 27.1654C13.7704 27.3355 15.1033 27.5 17.4091 27.5C20.1658 27.5 21.5319 27.2649 22.6289 27.0761L22.6571 27.0712C23.3225 26.9218 23.8578 26.2925 24.0258 25.4634C24.1647 24.4769 24.3182 22.0315 24.3182 20C24.3182 18.5797 24.2432 16.957 24.1473 15.773L12.755 27.1654ZM13.0606 14.375C12.6004 14.375 12.2273 14.7481 12.2273 15.2083V15.4167C12.2273 15.8769 12.6004 16.25 13.0606 16.25H13.9848C14.4451 16.25 14.8182 15.8769 14.8182 15.4167V15.2083C14.8182 14.7481 14.4451 14.375 13.9848 14.375H13.0606ZM26.0455 17.7232C26.0455 16.4904 27.1794 14.375 28.6364 14.375C29.5 14.375 29.5 17.9911 29.5 20C29.5 22.0089 29.4508 25.625 28.6364 25.625C26.8754 25.625 26.0455 23.7279 26.0455 22.2768V17.7232Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_4$6 = /*#__PURE__*/vue.createElementVNode("rect", {
  x: "24.8574",
  y: "11.8564",
  width: "1.5",
  height: "22",
  rx: ".75",
  transform: "rotate(45 24.8574 11.8564)",
  fill: "#FE3C44"
}, null, -1 /* HOISTED */);
const _hoisted_5$4 = [
  _hoisted_2$c,
  _hoisted_3$c,
  _hoisted_4$6
];

function render$8(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$d, _hoisted_5$4))
}

const script$d = {};


script$d.render = render$8;
script$d.__file = "src/icons/cameraClosedBig.vue";

const _hoisted_1$c = { class: "control-wrapper" };
const _hoisted_2$b = { class: "control-item-detail-row" };
const _hoisted_3$b = /*#__PURE__*/ vue.createElementVNode("div", null, " 摄像头", -1 /* HOISTED */);
const _hoisted_4$5 = {
    value: "",
    selected: "",
    disabled: "",
    hidden: ""
};
const _hoisted_5$3 = ["value"];
const _hoisted_6$3 = { key: 0 };
const _hoisted_7$1 = /*#__PURE__*/ vue.createElementVNode("div", null, " 分辨率 ", -1 /* HOISTED */);
const _hoisted_8$1 = /*#__PURE__*/ vue.createElementVNode("option", {
    value: "",
    selected: "",
    disabled: "",
    hidden: ""
}, "默认分辨率", -1 /* HOISTED */);
const _hoisted_9$1 = /*#__PURE__*/ vue.createElementVNode("option", {
    value: "480p",
    selected: ""
}, " 480p ", -1 /* HOISTED */);
const _hoisted_10$1 = /*#__PURE__*/ vue.createElementVNode("option", {
    value: "720p",
    selected: ""
}, " 720p ", -1 /* HOISTED */);
const _hoisted_11 = /*#__PURE__*/ vue.createElementVNode("option", {
    value: "1080p",
    selected: ""
}, " 1080p ", -1 /* HOISTED */);
const _hoisted_12 = [
    _hoisted_8$1,
    _hoisted_9$1,
    _hoisted_10$1,
    _hoisted_11
];
const _hoisted_13 = {
    value: "",
    selected: "",
    disabled: "",
    hidden: ""
};
const _hoisted_14 = ["value"];
var script$c = /*#__PURE__*/ vue.defineComponent({
    __name: 'ControlPanel',
    setup(__props) {
        const cameraList = vue.ref([]);
        const microphoneList = vue.ref([]);
        const currentCamera = vue.ref("");
        const currentMicrophone = vue.ref("");
        const currentVideoQuality = vue.ref("");
        const openCameraDetail = vue.ref(false);
        const openMicrophoneDetail = vue.ref(false);
        const freshDeviceList = async () => {
            cameraList.value = await TUICallKitServer.getDeviceList('camera');
            microphoneList.value = await TUICallKitServer.getDeviceList('microphones');
        };
        vue.onMounted(() => {
            freshDeviceList();
            document.documentElement.addEventListener('click', (e) => {
                openCameraDetail.value = false;
                openMicrophoneDetail.value = false;
            });
        });
        const hangup = () => {
            TUICallKitServer.hangup();
        };
        function switchCameraDevice() {
            TUICallKitServer.switchDevice("video", currentCamera.value);
            openCameraDetail.value = false;
        }
        const switchMicrophoneDevice = () => {
            TUICallKitServer.switchDevice('audio', currentMicrophone.value);
            openMicrophoneDetail.value = false;
        };
        const toggleCamera = async () => {
            if (profile.value?.camera) {
                await TUICallKitServer.closeCamera();
            }
            else {
                await TUICallKitServer.openCamera();
            }
        };
        const toggleMicrophone = async () => {
            if (profile.value?.microphone) {
                await TUICallKitServer.closeMicrophone();
            }
            else {
                await TUICallKitServer.openMicrophone();
            }
        };
        const setVideoQuality = async () => {
            await TUICallKitServer.setVideoQuality(currentVideoQuality.value);
        };
        const switchCallMediaType = async () => {
            await TUICallKitServer.switchCallMediaType();
        };
        function accept() {
            TUICallKitServer.accept();
        }
        function reject() {
            TUICallKitServer.reject();
        }
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$c, [
                (vue.unref(status) === vue.unref(STATUS).BE_INVITED)
                    ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
                        vue.createVNode(script$m, { action: reject }, {
                            text: vue.withCtx(() => [
                                vue.createTextVNode(" 拒绝 ")
                            ]),
                            icon: vue.withCtx(() => [
                                vue.createCommentVNode(" <img :src=\"rejectSVG\" /> "),
                                vue.createVNode(script$l)
                            ]),
                            _: 1 /* STABLE */
                        }),
                        vue.createVNode(script$m, { action: accept }, {
                            text: vue.withCtx(() => [
                                vue.createTextVNode(" 接听 ")
                            ]),
                            icon: vue.withCtx(() => [
                                (vue.unref(callType) === vue.unref(CALL_TYPE_STRING).AUDIO)
                                    ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
                                        vue.createCommentVNode(" <img :src=\"acceptAudioSVG\" /> "),
                                        vue.createVNode(script$k)
                                    ], 64 /* STABLE_FRAGMENT */))
                                    : (vue.unref(callType) === vue.unref(CALL_TYPE_STRING).VIDEO)
                                        ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
                                            vue.createCommentVNode(" <img :src=\"acceptVideoSVG\" /> "),
                                            vue.createVNode(script$j)
                                        ], 64 /* STABLE_FRAGMENT */))
                                        : vue.createCommentVNode("v-if", true)
                            ]),
                            _: 1 /* STABLE */
                        })
                    ], 64 /* STABLE_FRAGMENT */))
                    : (vue.unref(status) !== 'idle')
                        ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
                            (vue.unref(callType) === vue.unref(CALL_TYPE_STRING).VIDEO)
                                ? (vue.openBlock(), vue.createBlock(script$m, {
                                    key: 0,
                                    action: toggleCamera,
                                    hasDetail: true
                                }, {
                                    text: vue.withCtx(() => [
                                        vue.createTextVNode(" 摄像头已" + vue.toDisplayString(vue.unref(profile)?.camera ? "打开" : "关闭"), 1 /* TEXT */)
                                    ]),
                                    icon: vue.withCtx(() => [
                                        vue.createCommentVNode(" <img :src=\"cameraSVG\" v-if=\"profile?.camera\"/> "),
                                        vue.createCommentVNode(" <img :src=\"cameraClosedBigSVG\" v-if=\"!profile?.camera\"/> "),
                                        (vue.unref(profile)?.camera)
                                            ? (vue.openBlock(), vue.createBlock(script$i, { key: 0 }))
                                            : vue.createCommentVNode("v-if", true),
                                        (!vue.unref(profile)?.camera)
                                            ? (vue.openBlock(), vue.createBlock(script$d, { key: 1 }))
                                            : vue.createCommentVNode("v-if", true)
                                    ]),
                                    detail: vue.withCtx(() => [
                                        vue.createElementVNode("div", _hoisted_2$b, [
                                            _hoisted_3$b,
                                            vue.withDirectives(vue.createElementVNode("select", {
                                                class: "device-select",
                                                "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((currentCamera).value = $event)),
                                                onChange: switchCameraDevice
                                            }, [
                                                vue.createElementVNode("option", _hoisted_4$5, vue.toDisplayString(cameraList.value && cameraList.value[0]?.label), 1 /* TEXT */),
                                                (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(cameraList.value, (camera) => {
                                                    return (vue.openBlock(), vue.createElementBlock("option", {
                                                        value: camera.deviceId
                                                    }, vue.toDisplayString(camera.label), 9 /* TEXT, PROPS */, _hoisted_5$3));
                                                }), 256 /* UNKEYED_FRAGMENT */))
                                            ], 544 /* HYDRATE_EVENTS, NEED_PATCH */), [
                                                [vue.vModelSelect, currentCamera.value]
                                            ])
                                        ]),
                                        (vue.unref(status) === vue.unref(STATUS).DIALING_C2C)
                                            ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_6$3, [
                                                _hoisted_7$1,
                                                vue.withDirectives(vue.createElementVNode("select", {
                                                    class: "device-select",
                                                    "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => ((currentVideoQuality).value = $event)),
                                                    onChange: setVideoQuality
                                                }, _hoisted_12, 544 /* HYDRATE_EVENTS, NEED_PATCH */), [
                                                    [vue.vModelSelect, currentVideoQuality.value]
                                                ])
                                            ]))
                                            : vue.createCommentVNode("v-if", true)
                                    ]),
                                    _: 1 /* STABLE */
                                }))
                                : vue.createCommentVNode("v-if", true),
                            vue.createVNode(script$m, {
                                action: toggleMicrophone,
                                hasDetail: true
                            }, {
                                text: vue.withCtx(() => [
                                    vue.createTextVNode(" 麦克风已" + vue.toDisplayString(vue.unref(profile)?.microphone ? "打开" : "关闭"), 1 /* TEXT */)
                                ]),
                                icon: vue.withCtx(() => [
                                    vue.createCommentVNode(" <img :src=\"microphoneSVG\" v-if=\"profile?.microphone\"/> "),
                                    vue.createCommentVNode(" <img :src=\"microphoneClosedBigSVG\" v-if=\"!profile?.microphone\" /> "),
                                    (vue.unref(profile)?.microphone)
                                        ? (vue.openBlock(), vue.createBlock(script$h, { key: 0 }))
                                        : vue.createCommentVNode("v-if", true),
                                    (!vue.unref(profile)?.microphone)
                                        ? (vue.openBlock(), vue.createBlock(script$e, { key: 1 }))
                                        : vue.createCommentVNode("v-if", true)
                                ]),
                                detail: vue.withCtx(() => [
                                    vue.createElementVNode("div", null, [
                                        vue.createTextVNode(" 麦克风 "),
                                        vue.withDirectives(vue.createElementVNode("select", {
                                            class: "device-select",
                                            "onUpdate:modelValue": _cache[2] || (_cache[2] = ($event) => ((currentMicrophone).value = $event)),
                                            onChange: switchMicrophoneDevice
                                        }, [
                                            vue.createElementVNode("option", _hoisted_13, vue.toDisplayString(microphoneList.value && microphoneList.value[0]?.label), 1 /* TEXT */),
                                            (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(microphoneList.value, (microphone) => {
                                                return (vue.openBlock(), vue.createElementBlock("option", {
                                                    value: microphone.deviceId
                                                }, vue.toDisplayString(microphone.label), 9 /* TEXT, PROPS */, _hoisted_14));
                                            }), 256 /* UNKEYED_FRAGMENT */))
                                        ], 544 /* HYDRATE_EVENTS, NEED_PATCH */), [
                                            [vue.vModelSelect, currentMicrophone.value]
                                        ])
                                    ])
                                ]),
                                _: 1 /* STABLE */
                            }),
                            vue.createCommentVNode("v-if", true),
                            (vue.unref(status) === 'calling-c2c-video')
                                ? (vue.openBlock(), vue.createBlock(script$m, {
                                    key: 2,
                                    action: switchCallMediaType
                                }, {
                                    text: vue.withCtx(() => [
                                        vue.createTextVNode(" 视频转语音 ")
                                    ]),
                                    icon: vue.withCtx(() => [
                                        vue.createCommentVNode(" <img :src=\"switchSVG\" /> "),
                                        vue.createVNode(script$g)
                                    ]),
                                    _: 1 /* STABLE */
                                }))
                                : vue.createCommentVNode("v-if", true),
                            vue.createVNode(script$m, { action: hangup }, {
                                text: vue.withCtx(() => [
                                    vue.createTextVNode(" 挂断 ")
                                ]),
                                icon: vue.withCtx(() => [
                                    vue.createCommentVNode(" <img :src=\"hangupSVG\" /> "),
                                    vue.createVNode(script$f)
                                ]),
                                _: 1 /* STABLE */
                            })
                        ], 64 /* STABLE_FRAGMENT */))
                        : vue.createCommentVNode("v-if", true)
            ]));
        };
    }
});

script$c.__file = "src/components/ControlPanel.vue";

const _hoisted_1$b = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 15 24",
  class: "design-iconfont"
};
const _hoisted_2$a = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M13.8431 1.14248C14.6564 1.93792 14.7145 3.1923 14.0174 4.0533L13.8431 4.24463L5.91455 11.9997L13.8431 19.7554C14.6564 20.5508 14.7145 21.8052 14.0174 22.6662L13.8431 22.8575C13.0299 23.653 11.7475 23.7098 10.8672 23.028L10.6716 22.8575L1.15685 13.5511C0.343607 12.7556 0.285517 11.5013 0.982587 10.6402L1.15685 10.4489L10.6716 1.14248C11.5474 0.285841 12.9673 0.285841 13.8431 1.14248Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_3$a = [
  _hoisted_2$a
];

function render$7(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$b, _hoisted_3$a))
}

const script$b = {};


script$b.render = render$7;
script$b.__file = "src/icons/left.vue";

const _hoisted_1$a = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 15 24",
  class: "design-iconfont"
};
const _hoisted_2$9 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M1.15685 1.14248C0.343606 1.93792 0.285517 3.1923 0.982587 4.0533L1.15685 4.24463L9.08545 11.9997L1.15685 19.7554C0.343606 20.5508 0.285517 21.8052 0.982587 22.6662L1.15685 22.8575C1.9701 23.653 3.25255 23.7098 4.13282 23.028L4.32843 22.8575L13.8431 13.5511C14.6564 12.7556 14.7145 11.5013 14.0174 10.6402L13.8431 10.4489L4.32843 1.14248C3.45262 0.285841 2.03266 0.285841 1.15685 1.14248Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_3$9 = [
  _hoisted_2$9
];

function render$6(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$a, _hoisted_3$9))
}

const script$a = {};


script$a.render = render$6;
script$a.__file = "src/icons/right.vue";

const _hoisted_1$9 = { class: "calling-wrapper" };
const _hoisted_2$8 = { class: "turn-icon-container" };
const _hoisted_3$8 = { class: "turn-icon-container" };
const _hoisted_4$4 = { class: "tag" };
const _hoisted_5$2 = { class: "microphone-icon-container" };
const _hoisted_6$2 = ["id"];
const _hoisted_7 = {
    key: 0,
    class: "user-view-text-container"
};
const _hoisted_8 = { class: "user-view-info" };
const _hoisted_9 = { class: "tag" };
const _hoisted_10 = { class: "microphone-icon-container" };
var script$9 = /*#__PURE__*/ vue.defineComponent({
    __name: 'Calling-Group',
    setup(__props) {
        const currentPage = vue.ref(1);
        const currentPageRemoteList = vue.ref([]);
        const groupUserViewClass = vue.ref("group-user-view");
        const groupCallingContainerClass = vue.ref("group-calling-container");
        const userViewUserId = vue.ref("user-view-user-id");
        vue.watch(currentPageRemoteList, async () => {
            const userViewCount = currentPageRemoteList.value.length + 1;
            await vue.nextTick();
            groupUserViewClass.value = `group-user-view group-user-view-${userViewCount}`;
            groupCallingContainerClass.value = `group-calling-container group-calling-container-${userViewCount}`;
            userViewUserId.value = `user-view-user-id user-view-user-id-${userViewCount}`;
        });
        vue.watchEffect(() => {
            refreshCurrentPageRemoteList();
        });
        vue.onUpdated(() => {
            if (status.value === STATUS.DIALING_GROUP)
                return;
            renderUserView();
        });
        function refreshCurrentPageRemoteList() {
            let newPageList = [];
            for (let i = (currentPage.value - 1) * 8; i < (currentPage.value) * 8 && i < remoteList.value.length; i++) {
                newPageList.push(remoteList.value[i]);
            }
            currentPageRemoteList.value = newPageList;
        }
        async function renderUserView() {
            await vue.nextTick();
            TUICallKitServer.startLocalView('local');
            currentPageRemoteList.value.forEach((remoteUserItem) => {
                if (remoteUserItem.isEntered) {
                    TUICallKitServer.startRemoteView(remoteUserItem.userID);
                }
            });
        }
        function pageReduce() {
            if (currentPage.value > 1) {
                currentPage.value--;
            }
        }
        function pageIncrease() {
            if (currentPage.value < Math.floor((remoteList.value.length - 1) / 8 + 1)) {
                currentPage.value++;
            }
        }
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$9, [
                (vue.unref(remoteList).length > 8)
                    ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
                        vue.createElementVNode("div", {
                            class: "page-turn left",
                            onClick: pageReduce
                        }, [
                            vue.createElementVNode("div", _hoisted_2$8, [
                                vue.createCommentVNode(" <img :src=\"leftSVG\" /> "),
                                vue.createVNode(script$b)
                            ])
                        ]),
                        vue.createElementVNode("div", {
                            class: "page-turn right",
                            onClick: pageIncrease
                        }, [
                            vue.createElementVNode("div", _hoisted_3$8, [
                                vue.createCommentVNode(" <img :src=\"rightSVG\" /> "),
                                vue.createVNode(script$a)
                            ])
                        ])
                    ], 64 /* STABLE_FRAGMENT */))
                    : vue.createCommentVNode("v-if", true),
                vue.createElementVNode("div", {
                    class: vue.normalizeClass(groupCallingContainerClass.value)
                }, [
                    vue.createElementVNode("div", {
                        id: "local",
                        class: vue.normalizeClass(groupUserViewClass.value)
                    }, [
                        vue.createElementVNode("span", _hoisted_4$4, [
                            vue.createElementVNode("div", _hoisted_5$2, [
                                (vue.unref(profile)?.microphone)
                                    ? (vue.openBlock(), vue.createBlock(script$q, {
                                        key: 0,
                                        volume: vue.unref(profile)?.volume
                                    }, null, 8 /* PROPS */, ["volume"]))
                                    : (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
                                        vue.createCommentVNode(" <img :src=\"microphoneClosedSVG\" v-if=\"!profile?.microphone\" /> "),
                                        vue.createVNode(script$p)
                                    ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */))
                            ]),
                            vue.createTextVNode(" " + vue.toDisplayString(`${vue.unref(profile).userID} (me)`), 1 /* TEXT */)
                        ])
                    ], 2 /* CLASS */),
                    (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(currentPageRemoteList.value, (remoteUserItem) => {
                        return (vue.openBlock(), vue.createElementBlock("div", {
                            key: remoteUserItem.userID,
                            class: vue.normalizeClass(groupUserViewClass.value),
                            id: remoteUserItem.userID
                        }, [
                            (!remoteUserItem.isEntered || (vue.unref(isFromGroup) && vue.unref(callType) === vue.unref(CALL_TYPE_STRING).AUDIO))
                                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_7, [
                                    vue.createElementVNode("div", {
                                        class: vue.normalizeClass(userViewUserId.value)
                                    }, vue.toDisplayString(remoteUserItem.userID), 3 /* TEXT, CLASS */),
                                    vue.createElementVNode("div", _hoisted_8, vue.toDisplayString(remoteUserItem.isEntered ? "已经进入当前通话" : "等待接听..."), 1 /* TEXT */)
                                ]))
                                : vue.createCommentVNode("v-if", true),
                            vue.createElementVNode("span", _hoisted_9, [
                                vue.createElementVNode("div", _hoisted_10, [
                                    (remoteUserItem?.microphone)
                                        ? (vue.openBlock(), vue.createBlock(script$q, {
                                            key: 0,
                                            volume: remoteUserItem?.volume
                                        }, null, 8 /* PROPS */, ["volume"]))
                                        : (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
                                            vue.createCommentVNode(" <img :src=\"microphoneClosedSVG\" v-if=\"!remoteUserItem?.microphone\" /> "),
                                            vue.createVNode(script$p)
                                        ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */))
                                ]),
                                vue.createTextVNode(" " + vue.toDisplayString(remoteUserItem.userID), 1 /* TEXT */)
                            ])
                        ], 10 /* CLASS, PROPS */, _hoisted_6$2));
                    }), 128 /* KEYED_FRAGMENT */))
                ], 2 /* CLASS */)
            ]));
        };
    }
});

script$9.__file = "src/components/Calling-Group.vue";

const _hoisted_1$8 = {
  xmlns: "http://www.w3.org/2000/svg",
  fill: "none",
  viewBox: "0 0 16 16",
  class: "design-iconfont"
};
const _hoisted_2$7 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M13.733 6.99996C13.7997 6.99996 13.933 6.99996 13.9997 6.93329C14.133 6.86663 14.2663 6.73329 14.333 6.59996C14.3997 6.46663 14.3997 6.26663 14.333 6.06663C14.2663 5.99996 14.2663 5.93329 14.1997 5.86663L10.1997 1.86663C9.93301 1.59996 9.53301 1.59996 9.26634 1.86663C8.99967 2.13329 8.99967 2.53329 9.26634 2.79996L12.133 5.66663H1.99967C1.59967 5.66663 1.33301 5.93329 1.33301 6.33329C1.33301 6.73329 1.59967 6.99996 1.99967 6.99996H13.733ZM13.9997 8.99996H2.26634C2.19967 8.99996 2.06634 8.99996 1.99967 9.06663C1.86634 9.13329 1.73301 9.26663 1.66634 9.39996C1.59967 9.53329 1.59967 9.73329 1.66634 9.93329C1.73301 9.99996 1.73301 10.0666 1.79967 10.1333L5.79967 14.1333C5.93301 14.2666 6.13301 14.3333 6.26634 14.3333C6.39967 14.3333 6.59967 14.2666 6.73301 14.1333C6.99967 13.8666 6.99967 13.4666 6.73301 13.2L3.86634 10.3333H13.9997C14.3997 10.3333 14.6663 10.0666 14.6663 9.66663C14.6663 9.26663 14.3997 8.99996 13.9997 8.99996Z",
  fill: "#fff"
}, null, -1 /* HOISTED */);
const _hoisted_3$7 = [
  _hoisted_2$7
];

function render$5(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$8, _hoisted_3$7))
}

const script$8 = {};


script$8.render = render$5;
script$8.__file = "src/icons/switch2.vue";

const _hoisted_1$7 = { class: "calling-wrapper" };
const _hoisted_2$6 = { class: "tag" };
const _hoisted_3$6 = { class: "microphone-icon-container" };
const _hoisted_4$3 = ["id"];
const _hoisted_5$1 = { class: "tag" };
const _hoisted_6$1 = { class: "microphone-icon-container" };
var script$7 = /*#__PURE__*/ vue.defineComponent({
    __name: 'Calling-C2CVideo',
    setup(__props) {
        vue.onMounted(() => {
            refreshUserViewList();
        });
        vue.onUpdated(() => {
            refreshUserViewList();
        });
        const refreshUserViewList = async () => {
            await vue.nextTick();
            if (remoteList.value.length >= 1) {
                TUICallKitServer.startLocalView('local');
                TUICallKitServer.startRemoteView(remoteList.value[0].userID);
            }
        };
        const localClass = vue.ref('small');
        const remoteClass = vue.ref('large');
        const switchUserView = async () => {
            [localClass.value, remoteClass.value] = [remoteClass.value, localClass.value];
            await vue.nextTick();
            const largeView = document.getElementsByClassName('large')[0];
            const smallView = document.getElementsByClassName('small')[0];
            smallView.style.height = "200px";
            largeView.style.height = "100%";
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$7, [
                vue.createElementVNode("div", {
                    id: "local",
                    class: vue.normalizeClass(localClass.value)
                }, [
                    vue.createElementVNode("span", _hoisted_2$6, [
                        vue.createElementVNode("div", _hoisted_3$6, [
                            (vue.unref(profile)?.microphone)
                                ? (vue.openBlock(), vue.createBlock(script$q, {
                                    key: 0,
                                    volume: vue.unref(profile)?.volume
                                }, null, 8 /* PROPS */, ["volume"]))
                                : (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
                                    vue.createCommentVNode(" <img :src=\"microphoneClosedSVG\" v-if=\"!profile?.microphone\" /> "),
                                    vue.createVNode(script$p)
                                ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */))
                        ]),
                        vue.createTextVNode(" " + vue.toDisplayString(`${vue.unref(profile).userID} (me)`), 1 /* TEXT */)
                    ]),
                    vue.createElementVNode("div", {
                        class: "switch-large-small",
                        onClick: switchUserView
                    }, [
                        vue.createCommentVNode(" <img :src=\"switch2SVG\" /> "),
                        vue.createVNode(script$8)
                    ])
                ], 2 /* CLASS */),
                (vue.unref(remoteList).length >= 1)
                    ? (vue.openBlock(), vue.createElementBlock("div", {
                        key: 0,
                        id: vue.unref(remoteList)[0].userID,
                        class: vue.normalizeClass(remoteClass.value)
                    }, [
                        vue.createElementVNode("span", _hoisted_5$1, [
                            vue.createElementVNode("div", _hoisted_6$1, [
                                (vue.unref(remoteList)[0]?.microphone)
                                    ? (vue.openBlock(), vue.createBlock(script$q, {
                                        key: 0,
                                        volume: vue.unref(remoteList)[0].volume
                                    }, null, 8 /* PROPS */, ["volume"]))
                                    : (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
                                        vue.createCommentVNode(" <img :src=\"microphoneClosedSVG\"  v-if=\"!remoteList[0]?.microphone\"/> "),
                                        vue.createVNode(script$p)
                                    ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */))
                            ]),
                            vue.createTextVNode(" " + vue.toDisplayString(vue.unref(remoteList)[0].userID), 1 /* TEXT */)
                        ]),
                        vue.createElementVNode("div", {
                            class: "switch-large-small",
                            onClick: switchUserView
                        }, [
                            vue.createCommentVNode(" <img :src=\"switch2SVG\" /> "),
                            vue.createVNode(script$8)
                        ])
                    ], 10 /* CLASS, PROPS */, _hoisted_4$3))
                    : vue.createCommentVNode("v-if", true)
            ]));
        };
    }
});

script$7.__file = "src/components/Calling-C2CVideo.vue";

const _hoisted_1$6 = {
  width: "20",
  height: "20",
  viewBox: "0 0 20 20",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$5 = /*#__PURE__*/vue.createElementVNode("rect", {
  x: "0.769231",
  y: "0.769231",
  width: "18.4615",
  height: "18.4615",
  rx: "0.769231",
  stroke: "white",
  "stroke-width": "1.53846"
}, null, -1 /* HOISTED */);
const _hoisted_3$5 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M11.5385 12.3077C11.5385 11.8829 11.8829 11.5385 12.3077 11.5385H19.2308V18.4615C19.2308 18.8864 18.8864 19.2308 18.4616 19.2308H11.5385V12.3077Z",
  stroke: "white",
  "stroke-width": "1.53846"
}, null, -1 /* HOISTED */);
const _hoisted_4$2 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M0.769287 0.769226L8.9723 8.92412",
  stroke: "white",
  "stroke-width": "1.53846"
}, null, -1 /* HOISTED */);
const _hoisted_5 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M9.4967 4.71716V9.4486H4.74146",
  stroke: "white",
  "stroke-width": "1.53846",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_6 = [
  _hoisted_2$5,
  _hoisted_3$5,
  _hoisted_4$2,
  _hoisted_5
];

function render$4(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$6, _hoisted_6))
}

const script$6 = {};


script$6.render = render$4;
script$6.__file = "src/icons/minimize.vue";

const _hoisted_1$5 = {
    key: 0,
    class: "tui-call-kit"
};
var script$5 = /*#__PURE__*/ vue.defineComponent({
    __name: 'TUICallKit',
    props: {
        beforeCalling: { type: Function, required: false },
        afterCalling: { type: Function, required: false },
        onMinimized: { type: Function, required: false },
        allowedMinimized: { type: Boolean, required: false, default: true }
    },
    setup(__props) {
        const props = __props;
        const { beforeCalling, afterCalling, onMinimized, allowedMinimized } = props;
        TUICallKitServer.setCallback({ beforeCalling, afterCalling, onMinimized });
        function toggleMinimize() {
            TUICallKitServer.toggleMinimize();
        }
        return (_ctx, _cache) => {
            return (vue.unref(status) !== vue.unref(STATUS).IDLE)
                ? vue.withDirectives((vue.openBlock(), vue.createElementBlock("div", _hoisted_1$5, [
                    (vue.unref(status) !== vue.unref(STATUS).IDLE && vue.unref(allowedMinimized) === true && vue.unref(status) !== vue.unref(STATUS).DIALING_C2C && vue.unref(status) !== vue.unref(STATUS).DIALING_GROUP && vue.unref(status) !== vue.unref(STATUS).BE_INVITED)
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 0,
                            class: "minimize",
                            onClick: toggleMinimize
                        }, [
                            vue.createVNode(script$6)
                        ]))
                        : vue.createCommentVNode("v-if", true),
                    (vue.unref(status) === vue.unref(STATUS).BE_INVITED ||
                        vue.unref(status) === vue.unref(STATUS).DIALING_C2C ||
                        vue.unref(status) === vue.unref(STATUS).CALLING_C2C_AUDIO)
                        ? (vue.openBlock(), vue.createBlock(script$o, { key: 1 }))
                        : vue.createCommentVNode("v-if", true),
                    (vue.unref(status) === vue.unref(STATUS).CALLING_C2C_VIDEO)
                        ? (vue.openBlock(), vue.createBlock(script$7, { key: 2 }))
                        : vue.createCommentVNode("v-if", true),
                    (vue.unref(status) === vue.unref(STATUS).DIALING_GROUP ||
                        vue.unref(status) === vue.unref(STATUS).CALLING_GROUP_AUDIO ||
                        vue.unref(status) === vue.unref(STATUS).CALLING_GROUP_VIDEO)
                        ? (vue.openBlock(), vue.createBlock(script$9, { key: 3 }))
                        : vue.createCommentVNode("v-if", true),
                    (vue.unref(status) !== vue.unref(STATUS).IDLE)
                        ? (vue.openBlock(), vue.createBlock(script$c, { key: 4 }))
                        : vue.createCommentVNode("v-if", true)
                ], 512 /* NEED_PATCH */)), [
                    [vue.vShow, !vue.unref(isMinimized)]
                ])
                : vue.createCommentVNode("v-if", true);
        };
    }
});

script$5.__file = "src/components/TUICallKit.vue";

const _hoisted_1$4 = {
  width: "26",
  height: "26",
  viewBox: "0 0 26 26",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$4 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M18.4437 12.449C18.4437 14.1142 18.2336 15.3515 21.5089 15.7126C24.7875 16.0737 24.3666 13.6794 24.3662 12.0669C24.3649 10.2061 20.0602 7.61895 13.2726 7.6173C6.48662 7.61735 2.1789 10.205 2.17888 12.067C2.17887 13.68 1.75621 16.0726 5.03315 15.7123C8.31009 15.3537 8.10005 14.1155 8.09837 12.4495C8.10134 11.2862 10.7587 11.0316 13.2725 11.0298C15.7863 11.0281 18.4454 11.2844 18.4437 12.449Z",
  fill: "#FE3C44"
}, null, -1 /* HOISTED */);
const _hoisted_3$4 = [
  _hoisted_2$4
];

function render$3(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$4, _hoisted_3$4))
}

const script$4 = {};


script$4.render = render$3;
script$4.__file = "src/icons/floatCallEnd.vue";

const _hoisted_1$3 = {
  width: "20",
  height: "20",
  viewBox: "0 0 20 20",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$3 = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M6.66666 4.16668C6.66666 2.32834 8.16166 0.833344 9.99999 0.833344C11.8383 0.833344 13.3333 2.32834 13.3333 4.16668V9.16668C13.3333 11.005 11.8383 12.5 9.99999 12.5C8.16166 12.5 6.66666 11.005 6.66666 9.16668V4.16668ZM6.66666 18.3333C6.66666 17.8725 7.03999 17.5 7.49999 17.5H12.5C12.9608 17.5 13.3333 17.8725 13.3333 18.3333C13.3333 18.7942 12.9608 19.1667 12.5 19.1667H7.49999C7.03999 19.1667 6.66666 18.7942 6.66666 18.3333Z",
  fill: "#101419"
}, null, -1 /* HOISTED */);
const _hoisted_3$3 = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M15.8333 8.3512V9.50825C15.8333 12.081 13.2217 15 9.99999 15C6.77833 15 4.16666 12.081 4.16666 9.50825V8.33334",
  stroke: "#101419",
  "stroke-width": "1.66667",
  "stroke-linecap": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$1 = [
  _hoisted_2$3,
  _hoisted_3$3
];

function render$2(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$3, _hoisted_4$1))
}

const script$3 = {};


script$3.render = render$2;
script$3.__file = "src/icons/floatMicrophone.vue";

const _hoisted_1$2 = {
  width: "15",
  height: "21",
  viewBox: "0 0 15 21",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$2 = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M14.6247 0.719168C14.1934 0.374158 13.5641 0.44408 13.2191 0.875342L10.8168 3.83203C10.1789 3.02455 9.15387 2.50004 8.00001 2.50004C6.06976 2.50004 4.50001 3.96785 4.50001 5.77276V10.6819C4.50001 10.9563 4.5363 11.2229 4.60463 11.4778L3.388 12.9752C2.98449 12.3433 2.75001 11.6522 2.75001 10.9717V9.81819L2.74319 9.71556C2.6892 9.31213 2.32108 9.00001 1.87501 9.00001C1.39176 9.00001 1.00001 9.36632 1.00001 9.81819V10.9717L1.00466 11.1761C1.05557 12.2968 1.52161 13.4016 2.26939 14.3519L0.219137 16.8753L0.146861 16.9782C-0.112977 17.4017 -0.0227767 17.9624 0.375311 18.2809C0.806573 18.6259 1.43587 18.556 1.78088 18.1247L3.71661 15.7423C3.71849 15.7437 3.72038 15.745 3.72227 15.7464L4.2997 15.0246L8.28088 10.1247L14.7809 2.12473L14.8532 2.02191C15.113 1.59834 15.0228 1.03764 14.6247 0.719168ZM7.72499 13.9446L11.5 9.22582V10.6819C11.5 12.4868 9.93026 13.9546 8.00001 13.9546C7.90746 13.9546 7.81575 13.9512 7.72499 13.9446ZM6.60445 15.3453L5.50798 16.7159C6.29225 17.0136 7.13532 17.1818 8.00001 17.1818C11.6976 17.1818 15 14.1064 15 10.9717V9.83572L14.9932 9.73309C14.9392 9.32966 14.5711 9.01754 14.125 9.01754C13.6418 9.01754 13.25 9.38385 13.25 9.83572V10.9717L13.2445 11.1527C13.1138 13.3262 10.6589 15.5455 8.00001 15.5455C7.52424 15.5455 7.05501 15.4744 6.60445 15.3453ZM5.37501 18.8637C4.89201 18.8637 4.50001 19.2294 4.50001 19.6819C4.50001 20.1343 4.89201 20.5 5.37501 20.5H10.625C11.1089 20.5 11.5 20.1343 11.5 19.6819C11.5 19.2294 11.1089 18.8637 10.625 18.8637H5.37501Z",
  fill: "#101419"
}, null, -1 /* HOISTED */);
const _hoisted_3$2 = [
  _hoisted_2$2
];

function render$1(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$2, _hoisted_3$2))
}

const script$2 = {};


script$2.render = render$1;
script$2.__file = "src/icons/floatMicrophoneClosed.vue";

const _hoisted_1$1 = {
  width: "21",
  height: "21",
  viewBox: "0 0 21 21",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$1 = /*#__PURE__*/vue.createElementVNode("path", {
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  d: "M2.33337 9.33331H0.333374V0.99998C0.333374 0.63179 0.631851 0.333313 1.00004 0.333313L9.33338 0.333313V2.33331H3.74758L10.0405 8.62624L8.62627 10.0404L2.33337 3.74753V9.33331ZM18.3331 11.3333H20.3331V19.6666C20.3331 20.0348 20.0347 20.3333 19.6665 20.3333L11.3331 20.3333L11.3331 18.3333H16.9189L10.626 12.0403L12.0402 10.6261L18.3331 16.919V11.3333Z",
  fill: "#101419"
}, null, -1 /* HOISTED */);
const _hoisted_3$1 = [
  _hoisted_2$1
];

function render(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$1, _hoisted_3$1))
}

const script$1 = {};


script$1.render = render;
script$1.__file = "src/icons/fullScreen.vue";

const _hoisted_1 = {
    key: 0,
    class: "float-control-panel"
};
const _hoisted_2 = { class: "float-control-item-icon" };
const _hoisted_3 = { class: "float-control-item-icon" };
const _hoisted_4 = { class: "float-control-item-icon" };
var script = /*#__PURE__*/ vue.defineComponent({
    __name: 'TUICallKitMini',
    setup(__props) {
        function toggleMinimize() {
            TUICallKitServer.toggleMinimize();
        }
        const hangup = () => {
            TUICallKitServer.hangup();
        };
        const toggleMicrophone = async () => {
            if (profile.value?.microphone) {
                await TUICallKitServer.closeMicrophone();
            }
            else {
                await TUICallKitServer.openMicrophone();
            }
        };
        return (_ctx, _cache) => {
            return (vue.unref(status) !== vue.unref(STATUS).IDLE)
                ? vue.withDirectives((vue.openBlock(), vue.createElementBlock("div", _hoisted_1, [
                    vue.createElementVNode("div", _hoisted_2, [
                        vue.createElementVNode("div", {
                            class: "float-control-item-icon-container",
                            onClick: hangup
                        }, [
                            vue.createVNode(script$4)
                        ])
                    ]),
                    vue.createElementVNode("div", _hoisted_3, [
                        vue.createElementVNode("div", {
                            class: "float-control-item-icon-container",
                            onClick: toggleMicrophone
                        }, [
                            (vue.unref(profile)?.microphone)
                                ? (vue.openBlock(), vue.createBlock(script$3, { key: 0 }))
                                : vue.createCommentVNode("v-if", true),
                            (!vue.unref(profile)?.microphone)
                                ? (vue.openBlock(), vue.createBlock(script$2, { key: 1 }))
                                : vue.createCommentVNode("v-if", true)
                        ])
                    ]),
                    vue.createElementVNode("div", _hoisted_4, [
                        vue.createElementVNode("div", {
                            class: "float-control-item-icon-container",
                            onClick: toggleMinimize
                        }, [
                            vue.createVNode(script$1)
                        ])
                    ])
                ], 512 /* NEED_PATCH */)), [
                    [vue.vShow, vue.unref(isMinimized)]
                ])
                : vue.createCommentVNode("v-if", true);
        };
    }
});

script.__file = "src/components/TUICallKitMini.vue";

const TUICallKitServer = new TUICallKit();
const plugin = (TUICore) => {
    TUICore.component("TUICallKit", script$5);
    TUICore.component("TUICallKitMini", script);
    TUICallKitServer.bindTUICore(TUICore);
    return script$5;
};
const install = (app) => {
    app.component('TUICallKitMini', script);
    app.component('TUICallKit', script$5);
    console.log("TUICallKit&mini installed", app);
};
script$5.plugin = plugin;
script$5.install = install;

exports.STATUS = STATUS;
exports.TUICallKit = script$5;
exports.TUICallKitMini = script;
exports.TUICallKitServer = TUICallKitServer;
